/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.orchestra.lib.jsf;

import org.apache.myfaces.orchestra.frameworkAdapter.FrameworkAdapter;

import javax.faces.convert.Converter;
import javax.faces.convert.ConverterException;
import javax.faces.context.FacesContext;
import javax.faces.component.UIComponent;
import java.io.Serializable;

/**
 * Wraps a converter and serialize just its id to make it serializable.
 */
public class SerializableConverter implements Converter, Serializable
{
	private static final long serialVersionUID = 1L;

	private final String converterId;
	private transient Converter converter;

	public SerializableConverter(String converterId)
	{
		this.converterId = converterId;
	}

	public SerializableConverter(String converterId, Converter converter)
	{
		this(converterId);
		this.converter = converter;
	}

	protected Converter getConverter()
	{
		if (this.converter == null)
		{
			this.converter = (Converter) FrameworkAdapter.getCurrentInstance().getBean(this.converterId);
		}

		return this.converter;
	}

	public Object getAsObject(FacesContext context, UIComponent component, String value) throws ConverterException
	{
		return getConverter().getAsObject(context, component, value);
	}

	public String getAsString(FacesContext context, UIComponent component, Object value) throws ConverterException
	{
		return getConverter().getAsString(context, component, value);
	}
}
