/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.orchestra.viewController.spring;

import org.apache.myfaces.orchestra.conversation.Conversation;
import org.apache.myfaces.orchestra.conversation.ConversationContext;
import org.apache.myfaces.orchestra.conversation.spring.AbstractSpringOrchestraScope;
import org.apache.myfaces.orchestra.lib.OrchestraException;
import org.apache.myfaces.orchestra.viewController.ViewControllerManager;
import org.apache.myfaces.orchestra.viewController._ViewControllerUtils;

import javax.faces.context.FacesContext;

/**
 * provides a dummy scope which will place a bean configured for into the same conversation as the
 * viewController.
 */
public class SpringViewControllerScope extends AbstractSpringOrchestraScope
{
	public SpringViewControllerScope()
	{
	}

	public Conversation createConversation(ConversationContext context, String conversationName)
	{
		throw new IllegalStateException("the viewController scope is not supposed to start a conversation on its own. conversation to start: " + conversationName);
	}

    protected void assertSameScope(String beanName, Conversation conversation)
    {
        // since we do not start any conversation, there is no need to check
        // if this scope uses the same conversationFactory
    }

    protected String getConversationNameForBean(String beanName)
	{
		FacesContext facesContext = FacesContext.getCurrentInstance();

		ViewControllerManager viewControllerManager = _ViewControllerUtils.getViewControllerManager(facesContext);
		String viewControllerName = viewControllerManager.getViewControllerName(facesContext.getViewRoot().getViewId());
		if (viewControllerName == null)
		{
			throw new OrchestraException("no view controller name found for view " + facesContext.getViewRoot().getViewId());
		}

		String conversationName = super.getConversationNameForBean(viewControllerName);
		if (conversationName == null)
		{
			throw new OrchestraException("no view controller definition found for view " + facesContext.getViewRoot().getViewId());
		}

		return conversationName;
	}
}